==> apache-tez-0.7.0-src.tar.gz: apache-tez-0.7.0-src/tez-ui/src/main/webapp/app/scripts/mixins/auto-counter-column-mixin.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

App.AutoCounterColumnMixin = Em.Mixin.create({

  baseEntityType: null, // Must be set in the controller that uses this Mixin

  columnSelectorMessage: function () {
    return "<span class='per-io'>Per-IO counter</span> selection wouldn't persist across %@.".fmt(
      this.get('filterEntityType').pluralize()
    );
  }.property('filterEntityType'),

  columnConfigs: function() {
    var counterConfigs = App.Helpers.misc.normalizeCounterConfigs(
      App.get('Configs.defaultCounters').concat(
        App.get('Configs.tables.entity.' + this.get('baseEntityType')) || [],
        App.get('Configs.tables.sharedColumns') || []
      )
    ), dynamicCounterConfigs = [];

    this.get('data').forEach(function (row) {
      var counterGroups = row.get('counterGroups');
      if(counterGroups) {
        counterGroups.forEach(function (group) {
          group.counters.forEach(function (counter) {
            dynamicCounterConfigs.push({
              counterName: counter.counterName,
              counterGroupName: group.counterGroupName
            });
          });
        });
      }
    });

    return this.get('defaultColumnConfigs').concat(
      App.Helpers.misc.getUniqueByProperty(counterConfigs.concat(
        App.Helpers.misc.normalizeCounterConfigs(dynamicCounterConfigs)
      ), 'id')
    );
  }.property('data', 'defaultColumnConfigs', 'baseEntityType')

});

==> apache-tez-0.8.5-src.tar.gz: apache-tez-0.8.5-src/tez-ui/src/main/webapp/app/scripts/mixins/auto-counter-column-mixin.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

App.AutoCounterColumnMixin = Em.Mixin.create({

  baseEntityType: null, // Must be set in the controller that uses this Mixin

  columnSelectorMessage: function () {
    return "<span class='per-io'>Per-IO counter</span> selection wouldn't persist across %@.".fmt(
      this.get('filterEntityType').pluralize()
    );
  }.property('filterEntityType'),

  columnConfigs: function() {
    var counterConfigs = App.Helpers.misc.normalizeCounterConfigs(
      App.get('Configs.defaultCounters').concat(
        App.get('Configs.tables.entity.' + this.get('baseEntityType')) || [],
        App.get('Configs.tables.sharedColumns') || []
      )
    , this), dynamicCounterConfigs = [];

    this.get('data').forEach(function (row) {
      var counterGroups = row.get('counterGroups');
      if(counterGroups) {
        counterGroups.forEach(function (group) {
          group.counters.forEach(function (counter) {
            dynamicCounterConfigs.push({
              counterName: counter.counterName,
              counterGroupName: group.counterGroupName
            });
          });
        });
      }
    });

    return this.get('defaultColumnConfigs').concat(
      App.Helpers.misc.getUniqueByProperty(counterConfigs.concat(
        App.Helpers.misc.normalizeCounterConfigs(dynamicCounterConfigs)
      ), 'id')
    );
  }.property('data', 'defaultColumnConfigs', 'baseEntityType')

});
